..  venco.py research file created on June 15, 2021
    by Fabia Miorelli
    Licensed under CC BY 4.0: https://creativecommons.org/licenses/by/4.0/deed.en

.. _projects:

Research Application Context
===================================


Below are some examples of the main application context of venco.py:

- *Detailed assessment of the transport sector*

  - Role of synthetic fuels for transport
  - Evaluation of new mobility concepts

- *Comparison of modelling approaches*

  - Systematic comparison of energy system models
  - Comparison of flexibility options (Power system oriented vs user oriented charging)

- *Creation of a reference dataset and energy system models*

  - Creation of a reference energy system model for Germany
  - Creation of a reference German dataset

venco.py is also used in connection to other energy models such as:

- *REMix*

  - Capacity expansion and dispatch in REMix
  - Link to model: `REMix model <https://www.dlr.de/ve/en/desktopdefault.aspx/tabid-16034/25988_read-66795/>`_

- *AMIRIS*

  -  Agent-based market simulation in AMIRIS
  -  Link to model: `AMIRIS model <https://www.dlr.de/ve/en/desktopdefault.aspx/tabid-16023/25972_read-66759/>`_

